@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* gtksourcefile.c
+/*
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2014, 2015 - Sébastien Wilmet <swilmet@gnome.org>
@@ -24,8 +24,7 @@
 
 #include "gtksourcefile.h"
 #include "gtksourceencoding.h"
-#include "gtksourceview-enumtypes.h"
-#include "gtksourceview-i18n.h"
+#include "gtksource-enumtypes.h"
 
 /**
  * SECTION:file
@@ -40,6 +39,12 @@
  * properties). On a successful load or save operation, the #GtkSourceFile
  * properties are updated. If an operation fails, the #GtkSourceFile properties
  * have still the previous valid values.
+ *
+ * <warning>
+ * This class is no longer maintained, patches are not accepted. There is a
+ * better implementation in the
+ * <ulink url="https://wiki.gnome.org/Projects/Tepl">Tepl</ulink> library.
+ * </warning>
  */
 
 enum
